From 773ea887b8907722012eecd0d3c8c90765a0310c Mon Sep 17 00:00:00 2001
From: Theo Linkspfeifer <lastonestanding@tutanota.com>
Date: Wed, 18 Mar 2020 19:57:52 +0100
Subject: [PATCH] Rename "Disconnect" context menu entry in side pane (Bug
 #16558)

...to "Unmount" which is commonly used instead.
---
 thunar/thunar-shortcuts-view.c | 4 ++--
 thunar/thunar-tree-view.c      | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/thunar/thunar-shortcuts-view.c b/thunar/thunar-shortcuts-view.c
index f2ef48ecb..1ff455fac 100644
--- a/thunar/thunar-shortcuts-view.c
+++ b/thunar/thunar-shortcuts-view.c
@@ -1202,8 +1202,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
         gtk_widget_show (item);
 
-        /* append the "Disconnect" item */
-        item = gtk_menu_item_new_with_mnemonic (_("Disconn_ect"));
+        /* append the "Unmount" item */
+        item = gtk_menu_item_new_with_mnemonic (_("_Unmount"));
         gtk_widget_set_sensitive (item, thunar_device_can_eject (device));
         g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_shortcuts_view_eject), view);
         gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
diff --git a/thunar/thunar-tree-view.c b/thunar/thunar-tree-view.c
index 5dc1076f1..e3fc8947b 100644
--- a/thunar/thunar-tree-view.c
+++ b/thunar/thunar-tree-view.c
@@ -1346,8 +1346,8 @@ G_GNUC_END_IGNORE_DEPRECATIONS
         }
       else
         {
-          /* append the "Disconnect" menu action */
-          item = gtk_menu_item_new_with_mnemonic (_("Disconn_ect"));
+          /* append the "Unmount" menu action */
+          item = gtk_menu_item_new_with_mnemonic (_("_Unmount"));
           gtk_widget_set_sensitive (item, thunar_device_can_eject (device));
           g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (thunar_tree_view_action_eject), view);
           gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-- 
GitLab